@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2005 Nate Nielsen
+ * Copyright (C) 2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,21 +23,13 @@
 #ifndef __SEAHORSE_WINDOWS_H__
 #define __SEAHORSE_WINDOWS_H__
 
-#include <gpgme.h>
-
 #include "seahorse-context.h"
 
-GtkWindow*	seahorse_key_manager_show	        (SeahorseOperation *op);
-
 GtkWindow*  seahorse_keyserver_search_show      (GtkWindow *parent);
 
 GtkWindow*  seahorse_keyserver_sync_show        (GList *keys,
                                                  GtkWindow *parent);
 
-GtkWindow*  seahorse_keyserver_results_show     (SeahorseOperation *op,
-                                                 GtkWindow *parent,
-                                                 const gchar *search_text);
-
 void        seahorse_generate_select_show       (GtkWindow *parent);
 
 void        seahorse_delete_show                (GList *keys);
